.. _whatsnew_0930:

v0.9.3 (September 15, 2022)
---------------------------

Enhancements
~~~~~~~~~~~~
* New class and function translate module temperature model parameters
  :py:func:`~pvlib.temperature.GenericLinearModel`
  :py:func:`~pvlib.temperature.generic_linear`
  (:issue:`1442`, :pull:`1463`)
* Low resolution altitude lookup map
  :py:func:`~pvlib.location.lookup_altitude`
  (:issue:`1516`, :pull:`1518`)
* New module to calculate spectral mismatch from field spectral measurements
  :py:func:`~pvlib.spectrum.get_example_spectral_response`
  :py:func:`~pvlib.spectrum.get_am15g`
  :py:func:`~pvlib.spectrum.calc_spectral_mismatch_field`
  (:issue:`1523`, :pull:`1524`)
* Added Townsend-Powers monthly snow loss model:
  :py:func:`pvlib.snow.loss_townsend`
  (:issue:`1246`, :pull:`1251`, :pull:`1468`)

Documentation
~~~~~~~~~~~~~
* Clarified description of cross-axis slope in :py:mod:`pvlib.tracking` (:pull:`1530`)
* Removed the kwarg ``closed`` from ``pd.date_range`` in the examples since it is deprecated for pandas >= 1.4.0. (:pull:`1540`)

Contributors
~~~~~~~~~~~~
* João Guilherme (:ghuser:`joaoguilhermeS`)
* Nicolas Martinez (:ghuser:`nicomt`)
* Anton Driesse (:ghuser:`adriesse`)
* Cliff Hansen (:ghuser:`cwhanse`)
* Kevin Anderson (:ghuser:`kanderso-nrel`)
* Mark Mikofski (:ghuser:`mikofski`)
* Will Holmgren (:ghuser:`wholmgren`)
* Mark Campanelli (:ghuser:`markcampanelli`)
* Adam R. Jensen (:ghuser:`AdamRJensen`)
* Abhishek Parikh (:ghuser:`abhisheksparikh`)
* Taos Transue (:ghuser:`reepoi`)
* (:ghuser:`chiragpachori`)
